@@ -132,7 +132,7 @@ class TransmitterSerializer(serializers.ModelSerializer):
     mode_id = serializers.SerializerMethodField()
     uplink_mode = serializers.SerializerMethodField()
     alive = serializers.SerializerMethodField()
-    updated = serializers.DateTimeField(source='created')
+    updated = serializers.DateTimeField(source='reviewed')
 
     class Meta:
         model = Transmitter
