@@ -1,5 +1,4 @@
 """Defines functions and settings for the django admin interface"""
-from datetime import datetime
 from socket import error as socket_error
 
 from django.conf.urls import url
@@ -7,6 +6,7 @@ from django.contrib import admin, messages
 from django.http import HttpResponseRedirect
 from django.shortcuts import redirect
 from django.urls import reverse
+from django.utils.timezone import now
 
 from db.base.models import Artifact, DemodData, ExportedFrameset, LatestTleSet, Mode, Operator, \
     Satellite, Telemetry, Tle, Transmitter, TransmitterEntry, TransmitterSuggestion
@@ -95,9 +95,10 @@ class SatelliteAdmin(admin.ModelAdmin):
 class TransmitterEntryAdmin(admin.ModelAdmin):
     """Defines TransmitterEntry view in django admin UI"""
     list_display = (
-        'uuid', 'description', 'satellite', 'service', 'type', 'downlink_mode', 'uplink_mode',
-        'baud', 'downlink_low', 'downlink_high', 'downlink_drift', 'uplink_low', 'uplink_high',
-        'uplink_drift', 'reviewed', 'approved', 'status', 'created', 'citation', 'user'
+        'id', 'uuid', 'description', 'satellite', 'service', 'type', 'downlink_mode',
+        'uplink_mode', 'baud', 'downlink_low', 'downlink_high', 'downlink_drift', 'uplink_low',
+        'uplink_high', 'uplink_drift', 'citation', 'approved', 'status', 'created', 'created_by',
+        'reviewed', 'reviewer'
     )
     search_fields = ('satellite__id', 'uuid', 'satellite__name', 'satellite__norad_cat_id')
     list_filter = (
@@ -110,7 +111,21 @@ class TransmitterEntryAdmin(admin.ModelAdmin):
         'uplink_mode',
         'baud',
     )
-    readonly_fields = ('uuid', 'satellite')
+
+    def has_change_permission(self, request, obj=None):
+        return False
+
+    def has_add_permission(self, request):
+        return False
+
+    def has_delete_permission(self, request, obj=None):
+        return False
+
+    def get_actions(self, request):
+        actions = super().get_actions(request)
+        if 'delete_selected' in actions:
+            del actions['delete_selected']
+        return actions
 
 
 @admin.register(TransmitterSuggestion)
@@ -119,7 +134,7 @@ class TransmitterSuggestionAdmin(admin.ModelAdmin):
     list_display = (
         'uuid', 'description', 'satellite', 'service', 'type', 'downlink_mode', 'uplink_mode',
         'baud', 'downlink_low', 'downlink_high', 'downlink_drift', 'uplink_low', 'uplink_high',
-        'uplink_drift', 'status', 'created', 'citation', 'user'
+        'uplink_drift', 'citation', 'status', 'created', 'created_by'
     )
     search_fields = ('satellite__id', 'uuid', 'satellite__name', 'satellite__norad_cat_id')
     list_filter = (
@@ -129,14 +144,14 @@ class TransmitterSuggestionAdmin(admin.ModelAdmin):
         'baud',
         'service',
     )
-    readonly_fields = (
-        'uuid', 'description', 'status', 'type', 'uplink_low', 'uplink_high', 'uplink_drift',
-        'downlink_low', 'downlink_high', 'downlink_drift', 'downlink_mode', 'uplink_mode',
-        'invert', 'baud', 'satellite', 'reviewed', 'approved', 'created', 'citation', 'user',
-        'service'
-    )
     actions = ['approve_suggestion', 'reject_suggestion']
 
+    def has_change_permission(self, request, obj=None):
+        return False
+
+    def has_add_permission(self, request):
+        return False
+
     def get_actions(self, request):
         """Returns the actions a user can take on a TransmitterSuggestion
 
@@ -159,13 +174,9 @@ class TransmitterSuggestionAdmin(admin.ModelAdmin):
         queryset_size = len(queryset)
         for entry in queryset:
             entry.approved = True
-            entry.reviewed = True
-            entry.created = datetime.utcnow()
-            entry.user = request.user
+            entry.reviewed = now()
+            entry.reviewer = request.user
             entry.save()
-        # After creating the new approved entries, we update the suggestion entries as reviewed
-        # Note that queryset.update doesn't use model's save() that creates new entries
-        queryset.update(reviewed=True, approved=True)
         if queryset_size == 1:
             self.message_user(request, "Transmitter suggestion was successfully approved")
         else:
@@ -181,14 +192,10 @@ class TransmitterSuggestionAdmin(admin.ModelAdmin):
         """
         queryset_size = len(queryset)
         for entry in queryset:
-            entry.created = datetime.utcnow()
-            entry.user = request.user
             entry.approved = False
-            entry.reviewed = True
+            entry.reviewed = now()
+            entry.reviewer = request.user
             entry.save()
-        # After creating the new approved entries, we update the suggestion entries as reviewed
-        # Note that queryset.update doesn't use model's save() that creates new entries
-        queryset.update(reviewed=True, approved=False)
         if queryset_size == 1:
             self.message_user(request, "Transmitter suggestion was successfully rejected")
         else:
@@ -201,13 +208,12 @@ class TransmitterSuggestionAdmin(admin.ModelAdmin):
 class TransmitterAdmin(admin.ModelAdmin):
     """Defines Transmitter view in django admin UI"""
     list_display = (
-        'uuid', 'description', 'satellite', 'service', 'type', 'downlink_mode', 'uplink_mode',
-        'baud', 'downlink_low', 'downlink_high', 'downlink_drift', 'uplink_low', 'uplink_high',
-        'uplink_drift', 'status', 'created', 'citation', 'user'
-    )
-    search_fields = (
-        'satellite__id', 'uuid', 'description', 'satellite__name', 'satellite__norad_cat_id'
+        'id', 'uuid', 'description', 'satellite', 'service', 'type', 'downlink_mode',
+        'uplink_mode', 'baud', 'downlink_low', 'downlink_high', 'downlink_drift', 'uplink_low',
+        'uplink_high', 'uplink_drift', 'citation', 'status', 'created', 'created_by', 'reviewed',
+        'reviewer'
     )
+    search_fields = ('satellite__id', 'uuid', 'satellite__name', 'satellite__norad_cat_id')
     list_filter = (
         'type',
         'status',
@@ -216,7 +222,21 @@ class TransmitterAdmin(admin.ModelAdmin):
         'uplink_mode',
         'baud',
     )
-    readonly_fields = ('uuid', 'satellite')
+
+    def has_change_permission(self, request, obj=None):
+        return False
+
+    def has_add_permission(self, request):
+        return False
+
+    def has_delete_permission(self, request, obj=None):
+        return False
+
+    def get_actions(self, request):
+        actions = super().get_actions(request)
+        if 'delete_selected' in actions:
+            del actions['delete_selected']
+        return actions
 
 
 @admin.register(Tle)
