@@ -45,17 +45,15 @@ class TransmitterUpdateForm(BSModalModelForm):  # pylint: disable=too-many-ances
         fields = [
             'description', 'type', 'status', 'uplink_low', 'uplink_high', 'uplink_drift',
             'uplink_mode', 'downlink_low', 'downlink_high', 'downlink_drift', 'downlink_mode',
-            'invert', 'baud', 'citation', 'service', 'coordination', 'coordination_url', 'created'
+            'invert', 'baud', 'citation', 'service', 'coordination', 'coordination_url'
         ]
         labels = {
             'downlink_low': _('Downlink freq.'),
             'uplink_low': _('Uplink freq.'),
             'invert': _('Inverted Transponder?'),
-            'created': _('Updated'),
         }
         widgets = {
             'description': TextInput(),
-            'created': TextInput(attrs={'readonly': True}),
         }
 
 
