@@ -6,7 +6,7 @@ from bootstrap_modal_forms.generic import BSModalCreateView, BSModalUpdateView
 from django.conf import settings
 from django.contrib import messages
 from django.contrib.auth import get_user_model
-from django.contrib.auth.decorators import login_required, user_passes_test
+from django.contrib.auth.decorators import login_required
 from django.contrib.auth.mixins import LoginRequiredMixin, PermissionRequiredMixin
 from django.core.cache import cache
 from django.core.exceptions import ObjectDoesNotExist
@@ -16,7 +16,7 @@ from django.db.models import Count, Max, Prefetch, Q
 from django.http import HttpResponse, HttpResponseServerError, JsonResponse
 from django.shortcuts import get_object_or_404, redirect, render
 from django.urls import reverse
-from django.utils import timezone
+from django.utils.timezone import now
 from django.views.decorators.http import require_POST
 
 from db.base.forms import SatelliteModelForm, TransmitterModelForm, TransmitterUpdateForm
@@ -29,12 +29,6 @@ from db.base.utils import cache_statistics, millify, read_influx
 LOGGER = logging.getLogger('db')
 
 
-def superuser_check(user):
-    """Returns True if user is a superuser, for use with @user_passes_test
-    """
-    return user.is_superuser
-
-
 def home(request):
     """View to render home page.
 
@@ -55,7 +49,7 @@ def home(request):
     # Calculate latest contributors
     latest_data_satellites = []
     found = False
-    date_from = timezone.now() - timedelta(days=1)
+    date_from = now() - timedelta(days=1)
     data_list = DemodData.objects.filter(timestamp__gte=date_from).order_by('-pk')
     paginator = Paginator(data_list, 50)
     page = paginator.page(1)
@@ -77,7 +71,7 @@ def home(request):
     ).prefetch_related(prefetch_approved, prefetch_suggested)
 
     # Calculate latest contributors
-    date_from = timezone.now() - timedelta(days=1)
+    date_from = now() - timedelta(days=1)
     latest_submitters = DemodData.objects.filter(timestamp__gte=date_from
                                                  ).values('station').annotate(c=Count('station')
                                                                               ).order_by('-c')
@@ -132,7 +126,7 @@ def satellite(request, norad):
 
     :returns: base/satellite.html
     """
-    satellite_obj = get_object_or_404(Satellite.objects, norad_cat_id=norad)
+    satellite_obj = get_object_or_404(Satellite, norad_cat_id=norad)
 
     latest_tle = None
     latest_tle_set = None
@@ -199,34 +193,25 @@ def request_export(request, norad, period=None):
 
 @login_required
 @require_POST
-@user_passes_test(superuser_check)
 def transmitter_suggestion_handler(request):
-    """Returns the Satellite page after approving or rejecting a suggestion
+    """Returns the Satellite page after approving or rejecting a suggestion if
+    user has approve permission.
 
     :returns: Satellite page
     """
-    transmitter = TransmitterSuggestion.objects.get(uuid=request.POST['uuid'])
-    if 'approve' in request.POST:
-        transmitter.approved = True
-        messages.success(request, ('Transmitter approved.'))
-    elif 'reject' in request.POST:
-        transmitter.approved = False
-        messages.success(request, ('Transmitter rejected.'))
-    transmitter.reviewed = True
-    transmitter.created = timezone.now()
-    transmitter.user = request.user
+    transmitter = get_object_or_404(TransmitterSuggestion, pk=request.POST['pk'])
+    if request.user.has_perm('base.approve'):
+        if 'approve' in request.POST:
+            transmitter.approved = True
+            messages.success(request, ('Transmitter approved.'))
+        elif 'reject' in request.POST:
+            transmitter.approved = False
+            messages.success(request, ('Transmitter rejected.'))
+        transmitter.reviewed = now()
+        transmitter.reviewer = request.user
 
-    # Need to determine if we will attribute the suggestion or the approval
-    # transmitter.user = request.user
+        transmitter.save()
 
-    transmitter.save()
-
-    # the way we handle suggestions in admin is to update the suggestion as
-    # reviewed and save a new object. This feels hacky but preserves the
-    # admin workflow
-    TransmitterSuggestion.objects.filter(uuid=request.POST['uuid']).update(
-        reviewed=True, approved=transmitter.approved
-    )
     redirect_page = redirect(
         reverse('satellite', kwargs={'norad': transmitter.satellite.norad_cat_id})
     )
@@ -364,7 +349,9 @@ class TransmitterCreateView(LoginRequiredMixin, BSModalCreateView):
         """
         transmitter = form.instance
         transmitter.satellite = self.satellite
-        transmitter.user = self.user
+        transmitter.created = now()
+        transmitter.created_by = self.user
+        # Prevents sending notification twice as form_valid is triggered for validation and saving
         if not self.request.is_ajax():
             notify_transmitter_suggestion.delay(transmitter.satellite.id, self.user.id)
         return super().form_valid(form)
@@ -383,20 +370,20 @@ class TransmitterUpdateView(LoginRequiredMixin, BSModalUpdateView):
 
     user = get_user_model()
 
-    def get_initial(self):
-        initial = {}
-        initial['created'] = timezone.now()
-        return initial
-
     def dispatch(self, request, *args, **kwargs):
         self.user = request.user
         return super().dispatch(request, *args, **kwargs)
 
     def form_valid(self, form):
         transmitter = form.instance
-        transmitter.user = self.user
-        transmitter.reviewed = False
+        # Add update as a new TransmitterEntry object and change fields in order to be a suggestion
+        transmitter.pk = None
+        transmitter.reviewed = None
+        transmitter.reviewer = None
         transmitter.approved = False
+        transmitter.created = now()
+        transmitter.created_by = self.user
+        # Prevents sending notification twice as form_valid is triggered for validation and saving
         if not self.request.is_ajax():
             notify_transmitter_suggestion.delay(transmitter.satellite.id, self.user.id)
         return super().form_valid(form)
